Rdocumentation
powered by
Learn R Programming
wrspathrowData (version 1.0)
wrs1_asc_desc: Worldwide Reference System - 1 (WRS1) SpatialPolygonsDataFrame
Description
Contains polygons of the area of each path and row for the ascending and descending nodes of the WRS1 system.
Arguments
References
WRS-1 Shape files courtesy of the U.S. Geological Survey
.
See Also
wrs2_asc_desc