Rdocumentation
powered by
Learn R Programming
wrspathrowData (version 1.0)
wrs2_asc_desc: Worldwide Reference System - 2 (WRS2) SpatialPolygonsDataFrame
Description
Contains polygons of the area of each path and row for the ascending and descending nodes of the WRS2 system.
Arguments
References
WRS-2 Shape files courtesy of the U.S. Geological Survey
.
See Also
wrs1_asc_desc